;+
; NAME :	fmg_arpil (procedure)
; PURPOSE :
;	calculate the gradient of fmg cicular polarized data/longitudinal field 
;
; CATEGORY :
;	solar magnetic field computation package (ASOS/FMG)
; CALLING SEQUENCE :
;	fmg_arpil,filein, length, Xmax, Ymax, lonc_lmax, latc_lmax
; INPUTS :
;	filein   -- a fitsfile of cicular polarized data/longitudinal magnetic field
; OPTIONAL INPUT PARAMETERS :
;	none
; KEYWORD PARAMETERS :
;       Length:   total lenght of all the detected magnetic gradients in unit of Mm
;       xmax/ymax: position in the field of view 
;	lonc_lmax/latc_lmax:  position on the solar disk, [ ew, ns ]
;			 disk center => [0,0],  limb => +-1.
; OUTPUTS :
;	magnetic gardient map: the value is larger, the color is more deep.
; COMMON BLOCKS : 	none
; RESTRICTIONS :	none
; MODIFICATION HISTORY :
;       Chumak, O. V
;	Jiangtao Su, 2021/11, add the color to display the gradient strength 


pro fmg_arpil,filein, length, Xmax, Ymax, lonc_lmax, latc_lmax


nf1=n_elements(filein)
if nf1 eq 0 then begin
   print,'Please input a lev2.0 fmg-data file'
   return
endif


fxc=(4096-1.0)/2  ; the disk-center of raw data
fyc=(4096-1.0)/2

file_name=file_basename(filein)
sign=strmid(file_name,4,5)

if sign eq 'lev20' then begin
   read_fmg, filein, index, data, /strength
   dat=data(*,*,1)
endif else begin
   print,'This is not a lev2.0 data file'
   return
endelse

bl=smooth(dat,30,/edge_truncate)
fxc=(size(b1))[1]/2
fyc=(size(b1))[2]/2
pil_detect,bl,l, Lmax, Xmax, Ymax
l=l/(index.hdrbl.cdelt1*726./1000.)
pos_grad1=where(l gt 0,num1)
if num1 ne 0 then grad_xy = array_indices(l,pos_grad1)

Xmax_fd=Xmax+fxc-index.hdrbl.CRPIX1+1
Ymax_fd=Ymax+fyc-index.hdrbl.CRPIX2+1
xi=index.hdrbl.cdelt1*(Xmax_fd-fxc)
et=index.hdrbl.cdelt2*(Ymax_fd-fyc)
ll0=xy2lonlat([xi,et],index.hdrbl.DATE_OBS)
lonc_lmax=ll0[0]                               ;+sxpar(h,'CRLN_OBS')
latc_lmax=ll0[1]

pos_grad2=where(l gt 5, num2)
if num2 ne 0 then length=num2*index.hdrbl.cdelt1*726./1000.

s=size(dat)
window,0,xs=s(1),ys=s(2)
loadct,0
tvscl,dat>(-1500)<1500

loadct,33

for i=0,num1-1 do xyouts, grad_xy(0,i), grad_xy(1,i), '.', /devi,$
    color=255*(l(grad_xy(0,i),grad_xy(1,i))/max(l)),charsize=3,charthick=3

colorbar,pos=[0.5,0.10,0.8,0.125],/norm,range=[min(l),max(l)],$
         charsize=1.5,/bottom,charthick=1,yticks=7,xtitle='Gradient(BL) (Gauss/Mm)'
;
end

;fits15in=findfile('/media/sjt/data/fmg_test_data/asos/data/fmg/science/lev15/2017/09/07/ARs/fmg*.fits',count=n)
;fmg_arpil,fits15in,length,xmax,ymax,lon_lmax,latc_lmax
;xyouts,0.5,0.23,'Max. Grad(BL) position: 40.23, -9.44',charsize=2,charthick=1,/norm,color=0
;xyouts,0.5,0.20,'Length of All the PILs: 195.8589 Mm',charsize=2,charthick=1,/norm,color=0
